# 0.1.0
* Split functionality into two classes: PerfTimer() should be used for laboratory performance testing in controlled environment and Timer() can be used in production environments for observability purposes.

# 0.0.3
* Allow overriding printer function

# 0.0.2
* Implementation refactored

# 0.0.1
* Initial release
